@@ -1,6 +1,6 @@
 package Algorithm::Easing::Ease;
 
-use Moo;
+use Moose;
 
 use constant EPSILON => 0.000001;
 
@@ -43,12 +43,12 @@ Algorithm::Easing::Ease - This is the base class for an ease.
     Usage :
     
         Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
         Return :
-            p = position,
+            Let p be position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
