@@ -1,6 +1,6 @@
 package Algorithm::Easing::Linear;
 
-use Moo;
+use Moose;
 
 use Math::Trig qw(:pi);
 
@@ -54,8 +54,6 @@ Algorithm::Easing::Linear - Calculate eased translations between two positive wh
 
 =head1 SYNOPSIS
 
-        ## with mediator
-
         use Algorithm::Easing;
         use Algorithm::Easing::Linear;
 
@@ -91,15 +89,15 @@ Algorithm::Easing::Linear - Calculate eased translations between two positive wh
 =cut
 
 =head2 ease_none
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
@@ -108,15 +106,15 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_in($t,$b,$c,$d);
 
@@ -125,15 +123,15 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_out
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_out($t,$b,$c,$d);
 
@@ -142,15 +140,15 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_both
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
