@@ -1,6 +1,6 @@
 package Algorithm::Easing::Mediator;
 
-use Moo;
+use Moose;
 
 use Algorithm::Easing::Ease;
 use Math::Trig qw(:pi);
