@@ -1,6 +1,6 @@
 package Algorithm::Easing::Sinusoidal;
 
-use Moo;
+use Moose;
 
 use Math::Trig qw(:pi);
 
@@ -54,8 +54,6 @@ Algorithm::Easing::Sinusoidal - Calculate eased translations between two positiv
 
 =head1 SYNOPSIS
 
-        ## with mediator
-
         use Algorithm::Easing;
         use Algorithm::Easing::Sinusoidal;
 
@@ -91,15 +89,15 @@ Algorithm::Easing::Sinusoidal - Calculate eased translations between two positiv
 =cut
 
 =head2 ease_none
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_none($t,$b,$c,$d);
 
@@ -108,53 +106,53 @@ This method is used for a linear translation between two positive real whole int
 =cut
 
 =head2 ease_in
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_in($t,$b,$c,$d);
 
-This method is used to ease in between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in sinusoidal fashion.
+This method is used to ease in between two positive real whole integers using a positive real integer as the parameter for time in sinusoidal fashion.
 
 =cut
 
 =head2 ease_out
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_out($t,$b,$c,$d);
 
-This method is used to ease in between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in sinusoidal fashion.
+This method is used to ease in between two positive real whole integers using a positive real integer as the parameter for time in sinusoidal fashion.
 
 =cut
 
 =head2 ease_both
-    Usage :
+    usage :
     
-        Arguments : 
-            t = time,
-            b = begin,
-            c = change,
-            d = duration,
-        Return :
-            p = position,
+        Parameters : 
+            Let t be time,
+            Let b be begin,
+            Let c be change,
+            Let d be duration,
+        Results :
+            Let p be position,
             
         my $p = $obj->ease_both($t,$b,$c,$d);
 
-This method is used to ease both in then out between two positive real whole integers as an inward tween using a positive real integer as the parameter for time in sinusoidal.
+This method is used to ease both in then out between two positive real whole integers using a positive real integer as the parameter for time in sinusoidal.
 
 =cut
 
